==> myodbc2.50.26_2.50.26.orig.tar.gz: myodbc-2.50.26.orig/dialogs.h <==
/* Copyright Abandoned 1996 TCX DataKonsult AB & Monty Program KB & Detron HB
   This file is public domain and comes with NO WARRANTY of any kind */

/* Defines neaded for dialogs */

#include "resource.h"

#define MAXPATHLEN      (255+1)           // Max path length
#define MAXKEYLEN       (15+1)            // Max keyword length
#define MAXDESC         (255+1)           // Max description length
#define MAXDSNAME       (32+1)            // Max data source name length
#define MAXSERVER	(60+1)
#define MAXUSER		(16+1)
#define MAXPASSWORD	(16+1)
#define MAXSTMT		(255+1)

/* Attribute key indexes (into an array of Attr structs, see below */

#define KEY_DSN 		0
#define KEY_DESC		1
#define KEY_DB			2
#define KEY_SERVER		3
#define KEY_USER		4
#define KEY_PASSWORD		5
#define KEY_PORT                6
#define KEY_STMT		7
#define KEY_FLAG		8
#define NUMOFKEYS		9	// Number of keys supported
#define NUMOFBITS		18	/* Number of different options */

typedef struct tagAttr {
	BOOL  fSupplied;
	char  szAttr[MAXPATHLEN];
} Attr, FAR * LPAttr;


typedef struct tagSETUPDLG {
  SQLHWND	hwndParent; 			// Parent window handle
  LPCSTR	lpszDrvr;		// Driver description
  Attr	aAttr[NUMOFKEYS];		// Attribute array
  char	szDSN[MAXDSNAME];		// Original data source name
  BOOL	fNewDSN;			// New data source flag
  BOOL	fDefault;			// Default data source flag
  ulong config_flags;			/* Flags to affect myodbc behavour */
} SETUPDLG, FAR *LPSETUPDLG;


BOOL FAR PASCAL DriverConnectProc(HWND hdlg,WORD wMsg,WPARAM wParam,LPARAM lParam);
void INTFUNC ParseAttributes (LPCSTR lpszAttributes, LPSETUPDLG lpsetupdlg);
void set_attributes(LPSETUPDLG lpsetupdlg);

==> myodbc_2.50.39.orig.tar.gz: myodbc-2.50.39.orig/dialogs.h <==
/* Copyright Abandoned 1996 TCX DataKonsult AB & Monty Program KB & Detron HB
   This file is public domain and comes with NO WARRANTY of any kind */

/* Defines neaded for dialogs */

#include "resource.h"

#define MAXPATHLEN      (255+1)           // Max path length
#define MAXKEYLEN       (15+1)            // Max keyword length
#define MAXDESC         (255+1)           // Max description length
#define MAXDSNAME       (32+1)            // Max data source name length
#define MAXSERVER	(60+1)
#define MAXUSER		(32+1)
#define MAXPASSWORD	(32+1)
#define MAXSTMT		(255+1)

/* Attribute key indexes (into an array of Attr structs, see below */

#define KEY_DSN 		0
#define KEY_DESC		1
#define KEY_DB			2
#define KEY_SERVER		3
#define KEY_USER		4
#define KEY_PASSWORD		5
#define KEY_PORT                6
#define KEY_STMT		7
#define KEY_FLAG		8
#define NUMOFKEYS		10	// Number of keys supported
#define NUMOFBITS		19	/* Number of different options */
#define KEY_ERROR   		9

typedef struct tagAttr {
	my_bool fSupplied;
	char  szAttr[MAXPATHLEN];
} Attr, FAR * LPAttr;


typedef struct tagSETUPDLG {
  SQLHWND	hwndParent; 			// Parent window handle
  LPCSTR	lpszDrvr;		// Driver description
  Attr	aAttr[NUMOFKEYS];		// Attribute array
  char	szDSN[MAXDSNAME];		// Original data source name
  my_bool	fNewDSN;			// New data source flag
  my_bool	fDefault;			// Default data source flag
  ulong config_flags;			/* Flags to affect myodbc behavour */
} SETUPDLG, FAR *LPSETUPDLG;


int FAR PASCAL DriverConnectProc(HWND hdlg,WORD wMsg,WPARAM wParam,LPARAM lParam);
void INTFUNC ParseAttributes (LPCSTR lpszAttributes, LPSETUPDLG lpsetupdlg);
void set_attributes(LPSETUPDLG lpsetupdlg);
